@@ -56,7 +56,7 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
     def test_submit_tuxbuild_build(self):
         proc = self.submit_tuxbuild("tests/data/submit/tuxbuild/build.json")
         self.assertTrue(proc.ok, msg=proc.err)
-        self.assertTrue(proc.err.count("Submitting 1 tests") == 3)
+        self.assertTrue(proc.err.count("Submitting 1 tests, 1 metrics") == 3)
 
         build = (
             self.squad.group("my_group").project("my_project").build("next-20201021")
@@ -95,11 +95,19 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
         self.assertEqual("build/gcc-9-defconfig-5b09568e", test.name)
         self.assertEqual("fail", test.status)
 
+        metric = first(self.squad.metrics(name="gcc-9-defconfig-b9979cfa-warnings"))
+        self.assertEqual("build/gcc-9-defconfig-b9979cfa-warnings", metric.name)
+        self.assertEqual(1, metric.result)
+
+        metric = first(self.squad.metrics(name="gcc-9-defconfig-5b09568e-warnings"))
+        self.assertEqual("build/gcc-9-defconfig-5b09568e-warnings", metric.name)
+        self.assertEqual(2, metric.result)
+
     def test_submit_tuxbuild_buildset(self):
         os.environ["KERNEL_BRANCH"] = "master"
         proc = self.submit_tuxbuild("tests/data/submit/tuxbuild/buildset.json")
         self.assertTrue(proc.ok, msg=proc.out)
-        self.assertIn("Submitting 3 tests", proc.err)
+        self.assertIn("Submitting 3 tests, 3 metrics", proc.err)
 
         build = (
             self.squad.group("my_group").project("my_project").build("next-20201030")
@@ -131,6 +139,18 @@ class SubmitTuxbuildCommandTest(unittest.TestCase):
         self.assertEqual("build/gcc-8-x86_64_defconfig", test.name)
         self.assertEqual("pass", test.status)
 
+        metric = first(self.squad.metrics(name="gcc-8-allnoconfig-warnings"))
+        self.assertEqual("build/gcc-8-allnoconfig-warnings", metric.name)
+        self.assertEqual(0, metric.result)
+
+        metric = first(self.squad.metrics(name="gcc-8-tinyconfig-warnings"))
+        self.assertEqual("build/gcc-8-tinyconfig-warnings", metric.name)
+        self.assertEqual(0, metric.result)
+
+        metric = first(self.squad.metrics(name="gcc-8-x86_64_defconfig-warnings"))
+        self.assertEqual("build/gcc-8-x86_64_defconfig-warnings", metric.name)
+        self.assertEqual(0, metric.result)
+
     def test_submit_tuxbuild_empty(self):
         proc = self.submit_tuxbuild("")
         self.assertFalse(proc.ok, msg=proc.err)
